@@ -1,4 +1,8 @@
 #' 
+#' In general, this function is used to edit one parameter at a time. There are some exceptions. \cr
+#' 
+#'  - For the Clock, both the \sQuote{Start} and \sQuote{End} can be edited in one call.
+#' 
 #' @title Inspect an .apsimx (JSON) file
 #' @name inspect_apsimx
 #' @description inspect a JSON apsimx file. It does not replace the GUI, but it can save time by quickly checking parameters and values.
@@ -64,7 +68,7 @@ inspect_apsimx <- function(file = "", src.dir = ".",
   node <- match.arg(node)
   soil.child <- match.arg(soil.child)
   
-  if(soil.child %in% c("Nutrient")) stop("Not implemented yet")
+  if(soil.child %in% c("Nutrient")) stop("Not implemented yet", call. = FALSE)
   
   ## This matches the specified file from a list of files
   ## Notice that the .apsimx extension will be added here
@@ -82,8 +86,10 @@ inspect_apsimx <- function(file = "", src.dir = ".",
     if(missing(root)){
       cat("Simulation structure: \n")
       str_list(apsimx_json)
-      stop("more than one simulation found and no root node label has been specified \n select one of the children names above")   
+      stop("more than one simulation found and no root node label has been specified \n select one of the children names above", call. = FALSE)   
     }else{
+      if(length(root) > 3)
+        stop("At the moment 3 is the maximum length for root for this function", call. = FALSE)
       if(length(root) == 1){
         nms <- vapply(apsimx_json$Children, FUN = function(x) x$Name, 
                       FUN.VALUE = "character")
@@ -93,15 +99,37 @@ inspect_apsimx <- function(file = "", src.dir = ".",
         if(length(fcsn) == 0 || length(fcsn) > 1)
           stop("no root node label found or root is not unique")
       }else{
-        nms1 <- vapply(apsimx_json$Children, FUN = function(x) x$Name, 
-                      FUN.VALUE = "character")
-        fcsn1 <- grep(as.character(root[1]), nms1)
-        root.node.0 <- apsimx_json$Children[[fcsn1]]
-        root.node.0.child.names <- vapply(root.node.0$Children, function(x) x$Name, 
-                                          FUN.VALUE = "character")
-        fcsn2 <- grep(as.character(root[2]), root.node.0.child.names)
-        parent.node <- apsimx_json$Children[[fcsn1]]$Children[[fcsn2]]$Children
-        parm.path.1 <- paste0(parm.path.0,".",apsimx_json$Children[[fcsn1]]$Children[[fcsn2]])
+        if(length(root) == 2){
+          root.node.0.names <- sapply(apsimx_json$Children, function(x) x$Name)
+          wcore1 <- grep(as.character(root[1]), root.node.0.names)
+          if(length(wcore1) == 0 || length(wcore1) > 1)
+            stop("no root node label in position 1 found or root is not unique")
+          root.node.0 <- apsimx_json$Children[[wcore1]]
+          root.node.0.child.names <- sapply(root.node.0$Children, function(x) x$Name)  
+          wcore2 <- grep(as.character(root[2]), root.node.0.child.names)
+          if(length(wcore2) == 0 || length(wcore2) > 1)
+            stop("no root node label in position 2 found or root is not unique")
+          parent.node <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children        
+          parm.path.1 <- paste0(parm.path.0,".",apsimx_json$Children[[wcore1]]$Children[[wcore2]])
+        }
+        if(length(root) == 3){
+          root.node.0.names <- sapply(apsimx_json$Children, function(x) x$Name)
+          wcore1 <- grep(as.character(root[1]), root.node.0.names)
+          if(length(wcore1) == 0 || length(wcore1) > 1)
+            stop("no root node label in position 1 found or root is not unique")
+          root.node.0 <- apsimx_json$Children[[wcore1]]
+          root.node.0.child.names <- sapply(root.node.0$Children, function(x) x$Name)
+          wcore2 <- grep(as.character(root[2]), root.node.0.child.names)
+          if(length(wcore2) == 0 || length(wcore2) > 1)
+            stop("no root node label in position 2 found or root is not unique")
+          root.node.1 <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]
+          root.node.1.child.names <- sapply(root.node.1$Children, function(x) x$Name)  
+          wcore3 <- grep(as.character(root[3]), root.node.1.child.names)
+          if(length(wcore3) == 0 || length(wcore3) > 1)
+            stop("no root node label in position 3 found or root is not unique")
+          parent.node <- apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children[[wcore3]]$Children
+          parm.path.1 <- paste0(parm.path.0,".",apsimx_json$Children[[wcore1]]$Children[[wcore2]]$Children[[wcore3]])
+        }
       }
     }
   }else{
@@ -110,7 +138,7 @@ inspect_apsimx <- function(file = "", src.dir = ".",
   }
   
   if(node == "Clock"){
-    wlc <- function(x) grepl("Clock", x$Name, ignore.case = TRUE)
+    wlc <- function(x) grepl("Models.Clock", x$`$type`, ignore.case = TRUE)
     wlcl <- sapply(parent.node, FUN = wlc)
     if(all(wlcl == FALSE)){
       stop("Clock not found")
@@ -131,7 +159,7 @@ inspect_apsimx <- function(file = "", src.dir = ".",
   ## The previous creates a list
   if(node == "Weather"){
     ## Extract the list which has a component Name == "Weather"
-    wlw <- function(x) grepl("Weather", x$Name)
+    wlw <- function(x) grepl("Models.Climate.Weather|Models.Weather", x$`$type`)
     wlwl <- sapply(parent.node, FUN = wlw)
     if(all(wlwl == FALSE)){
       stop("Weather not found")
@@ -208,8 +236,9 @@ inspect_apsimx <- function(file = "", src.dir = ".",
       ## Assuming there is only one 'relevant' level here
       ## This parameter level would be 2.1.1
       parm.path <- paste0(parm.path.2.1,".",selected.soil.node.child[[1]]$Name) 
-      enms <- c("IncludeInDocumentation", "Enabled", "ReadOnly", "Children", "Name")
+      enms <- c("IncludeInDocumentation", "Enabled", "ReadOnly", "Children", "Name", "$type")
       cnms <- setdiff(names(selected.soil.node.child[[1]]), enms)
+      ## print(names(selected.soil.node.child[[1]]))
       
       if(soil.child == "Physical" || soil.child == "Water")
         cnms <- c(cnms, "Crop LL", "Crop KL", "Crop XF")
@@ -267,21 +296,50 @@ inspect_apsimx <- function(file = "", src.dir = ".",
           print(knitr::kable(soil.d3, digits = digits))
         }
       }else{
+        parm.physical.found <- FALSE
         ## Print first set of soil parameters
-        if(!is.null(soil.d1)) print(knitr::kable(soil.d1[soil.d1$parm == parm,], digits = digits))  
+        if(!is.null(soil.d1)){
+          if(parm %in% names(soil.d1)){
+            ##print(knitr::kable(soil.d1[soil.d1$parm == parm,], digits = digits))    
+            print(knitr::kable(soil.d1[, parm, drop = FALSE], digits = digits))    
+            parm.physical.found <- TRUE
+          }
+          if(parm %in% soil.d1$parm){
+            print(knitr::kable(soil.d1[soil.d1$parm == parm,], digits = digits))    
+            parm.physical.found <- TRUE
+          }
+        } 
         ## Print second set of soil parameters
         if(!is.null(soil.d2)){ 
           soil.d2 <- as.data.frame(soil.d2)
           names(soil.d2) <- col.nms
-          print(knitr::kable(soil.d2[soil.d2$parm == parm,], digits = digits))
+          ## print(knitr::kable(soil.d2[soil.d2$parm == parm,], digits = digits))
+          if(parm %in% names(soil.d2)){
+            print(knitr::kable(soil.d2[, parm, drop = FALSE], digits = digits))  
+            parm.physical.found <- TRUE
+          }
+          if(parm %in% soil.d2$parm){
+            print(knitr::kable(soil.d2[soil.d2$parm == parm,], digits = digits))    
+            parm.physical.found <- TRUE
+          }
         }
         ## Print third set of crop-soil parameters
         if(!is.null(soil.d3)){ 
           soil.d3 <- as.data.frame(soil.d3)
           names(soil.d3) <- d3.col.nms
           soil.d3 <- subset(soil.d3, select = sort(names(soil.d3)))
-          print(knitr::kable(soil.d3[soil.d3$parm == parm,], digits = digits))
+          ##print(knitr::kable(soil.d3[soil.d3$parm == parm,], digits = digits))
+          if(parm %in% names(soil.d3)){
+            print(knitr::kable(soil.d3[, parm, drop = FALSE], digits = digits))  
+            parm.physical.found <- TRUE
+          }
+          if(parm %in% soil.d3$parm){
+            print(knitr::kable(soil.d3[soil.d3$parm == parm,], digits = digits))    
+            parm.physical.found <- TRUE
+          }
         }
+        if(!parm.physical.found)
+          stop("Soil physical parameter not found", call. = FALSE)
       }
     }
   }
@@ -300,7 +358,15 @@ inspect_apsimx <- function(file = "", src.dir = ".",
     som.d <- data.frame(parm = names(som.node)[2:8],
                         value = as.vector(unlist(som.node)[2:8]))
     
-    print(knitr::kable(som.d, digits = digits))
+    if(missing(parm)){
+      print(knitr::kable(som.d, digits = digits))  
+    }else{
+      if(parm %in% som.d$parm){
+        print(knitr::kable(som.d[som.d$parm == parm, ], digits = digits))  
+      }else{
+        stop("Surface OM parameter not found", call. = FALSE)
+      }
+    }
   }
   
   if(node == "MicroClimate"){
@@ -315,7 +381,16 @@ inspect_apsimx <- function(file = "", src.dir = ".",
 
     microclimate.d <- data.frame(parm = names(microclimate.node)[2:9],
                                  value = as.vector(unlist(microclimate.node)[2:9]))
-    print(knitr::kable(microclimate.d, digits = digits))
+    
+    if(missing(parm)){
+      print(knitr::kable(microclimate.d, digits = digits))  
+    }else{
+      if(parm %in% microclimate.d$parm){
+        print(knitr::kable(microclimate.d[microclimate.d$parm == parm, ], digits = digits))  
+      }else{
+        stop("MicroClimate parameter not found", call. = FALSE)
+      }
+    }
   }
   
   if(node == "Crop"){
@@ -557,7 +632,7 @@ inspect_apsimx_json <- function(file = "", src.dir = ".", parm,
   .check_apsim_name(src.dir)
   
   if(missing(parm))
-    stop("You need to specify the parm argument")
+    stop("You need to specify the parm argument", call. = FALSE)
   
   file.names.apsimx <- dir(path = src.dir, pattern = ".apsimx$", ignore.case = TRUE)
   file.names.json <- dir(path = src.dir, pattern = ".json$", ignore.case = TRUE)
