@@ -1,5 +1,6 @@
 ## Testing the edit function with a variety of files
 require(apsimx)
+apsimx_options(warn.versions = FALSE)
 
 extd.dir <- system.file("extdata", package = "apsimx")
 
@@ -171,6 +172,27 @@ if(run.apsimx.edit){
              value = "[Wheat].EndOfDay")
  
  inspect_apsimx("Wheat-edited.apsimx", src.dir = tmp.dir, node = "Report")
+ 
+ ## Running soil carbon
+ edit_apsimx("Wheat.apsimx", src.dir = ex.dir,
+             node = "Report", wrt.dir = tmp.dir,
+             parm = "VariableNames",
+             value = "[Soil].Nutrient.Organic.C",
+             edit.tag = "-carbon")
+ 
+ inspect_apsimx("Wheat-carbon.apsimx", src.dir = tmp.dir, node = "Report")
+ 
+ sim.o <- apsimx("Wheat-carbon.apsimx", src.dir = tmp.dir)
+ 
+ edit_apsimx("Soybean.apsimx", src.dir = ex.dir,
+             node = "Report", wrt.dir = tmp.dir,
+             parm = "VariableNames",
+             value = "[Soil].Nutrient.Organic.C",
+             edit.tag = "-carbon")
+ 
+ inspect_apsimx("Soybean-carbon.apsimx", src.dir = tmp.dir, node = "Report")
+ 
+ sim.o <- apsimx("Soybean-carbon.apsimx", src.dir = tmp.dir)
   
 }
 
@@ -193,4 +215,25 @@ if(run.apsimx.edit){
   
   file.copy(file.path(tmp.dir, "Wheat.apsimx"), ".")
   
+}
+
+## Testing changing variables in the outputfile
+if(run.apsimx.edit){
+ 
+  extd.dir <- system.file("extdata", package = "apsimx")
+  file.copy(file.path(extd.dir, "Millet.apsim"), tmp.dir)
+  
+  inspect_apsim("Millet.apsim", src.dir = tmp.dir, node = "Outputfile", parm = "title")
+
+  edit_apsim("Millet.apsim", src.dir = tmp.dir,
+             node = "Outputfile", parm = "variables", 
+             value = "surfaceom_wt")
+    
+  edit_apsim("Millet.apsim", src.dir = tmp.dir,
+             node = "Outputfile",
+             parm = "variables", value = "surfaceom_wt")
+  
+  inspect_apsim("Millet-edited.apsim", src.dir = tmp.dir, 
+                node = "Outputfile", parm = "variables")
+  
 }
\ No newline at end of file
